@@ -4,7 +4,7 @@ Lager CLI
 A Command Line Interface for Lager Data
 """
 
-__version__ = '0.1.109'
+__version__ = '0.1.142'
 
 SUPPORTED_DEVICES = (
     'at91samdexx',
@@ -18,6 +18,7 @@ SUPPORTED_DEVICES = (
     'cc3235sf',
     'efm32',
     'nrf52',
+    'nrf91',
     'stm32f0x',
     'stm32f1x',
     'stm32f2x',
@@ -43,6 +44,7 @@ SUPPORTED_DEVICES = (
     'MIMXRT1064xxx5A',
     'MIMXRT1064xxx6A',
     'lpc54xx',
+    'nRF9160_xxAA',
     'lpc55xx',
     'pic32mm',
 )  # Empty docstring below is to suppress tuple docstring that would otherwise be printed by autodoc
@@ -56,4 +58,5 @@ SUPPORTED_INTERFACES = (
     'xds110',
     'stlink',
     'stlink-dap',
+    'third-party',
 )
