@@ -115,7 +115,7 @@ async def local_connection_handler(session, gateway, remote_host, remote_port, g
     finally:
         click.echo(f'client disconnected: {sockname}')
 
-async def serve_tunnel(host, port, connection_params, name, debug=True, *, task_status=trio.TASK_STATUS_IGNORED):
+async def serve_tunnel(host, port, connection_params, name, debug=True, rtt=None, rtt_port=None, *, task_status=trio.TASK_STATUS_IGNORED):
     """
         Start up the server that tunnels traffic to a gdbserver instance running on a gateway
     """
@@ -123,8 +123,15 @@ async def serve_tunnel(host, port, connection_params, name, debug=True, *, task_
         handler = functools.partial(cloud_connection_handler, connection_params, debug=debug)
         serve_listeners = functools.partial(trio.serve_tcp, handler, port, host=host)
 
+        if rtt:
+            rtt_handler = functools.partial(cloud_connection_handler, rtt, debug=debug)
+            rtt_serve_listeners = functools.partial(trio.serve_tcp, rtt_handler, rtt_port, host=host)
+            await nursery.start(rtt_serve_listeners)
+            click.echo(f'Serving RTT on {host}:{rtt_port}')
+
         server = await nursery.start(serve_listeners)
         task_status.started(server)
+
         if name and debug:
             click.echo(f'Serving {name} on {host}:{port}. Press Ctrl+C to quit.')
         try:
