@@ -98,7 +98,7 @@ def _get_signal_number(name):
 @click.command()
 @click.pass_context
 @click.argument('runnable', required=False, type=click.Path(exists=True))
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--gateway', '--dut', required=False, help='ID of gateway to which DUT is connected')
 @click.option('--image', default='lagerdata/gatewaypy3:v0.1.84', help='Docker image to use for running script', show_default=True)
 @click.option(
     '--env',
