@@ -15,7 +15,7 @@ from ..status import run_job_output
 
 @click.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--gateway', '--dut', required=False, help='ID of gateway to which DUT is connected')
 @click.option('--serial-device', '--serial-port', help='Gateway serial port device path', metavar='path')
 @click.option('--baudrate', help='Serial baud rate', type=int, default=None)
 @click.option('--bytesize', help='Number of data bits', type=click.Choice(['5', '6', '7', '8']), default=None)
@@ -37,6 +37,10 @@ from ..status import run_job_output
     multiple=True, type=BinfileType(exists=True),
     help='Binfile(s) to flash. Syntax: --binfile `<filename>,<address>` '
          'May be passed multiple times; files will be flashed in order.')
+@click.option(
+    '--elffile',
+    multiple=True, type=click.Path(exists=True),
+    help='Elf file(s) to flash. May be passed multiple times; files will be flashed in order.')
 @click.option(
     '--preverify/--no-preverify',
     help='If true, only flash target if image differs from current flash contents',
@@ -45,16 +49,17 @@ from ..status import run_job_output
 @click.option('--display-job-id', default=False, is_flag=True)
 @click.option('--success-regex', help='Line regex for detecting a successful test. Will be passed to Python\'s re.compile', default=None, required=False)
 @click.option('--failure-regex', help='Line regex for detecting a failed test. Will be passed to Python\'s re.compile', default=None, required=False)
+@click.option('--mcu', required=False, default=None, help='MCU to target', type=click.INT)
 def testrun(ctx, gateway, serial_device, baudrate, bytesize, parity, stopbits, xonxoff, rtscts,
-            dsrdtr, test_runner, interactive, message_timeout, overall_timeout, hexfile, binfile,
-            preverify, verify, display_job_id, success_regex, failure_regex):
+            dsrdtr, test_runner, interactive, message_timeout, overall_timeout, hexfile, binfile, elffile,
+            preverify, verify, display_job_id, success_regex, failure_regex, mcu):
     """
         Flash and run test on a DUT connected to a gateway
     """
     if gateway is None:
         gateway = get_default_gateway(ctx)
     session = ctx.obj.session
-    resp = do_reset(session, gateway, halt=True)
+    resp = do_reset(session, gateway, halt=True, mcu=mcu)
     stream_output(resp)
 
     resp = do_uart(
@@ -63,10 +68,10 @@ def testrun(ctx, gateway, serial_device, baudrate, bytesize, parity, stopbits, x
     )
     test_run = resp.json()
 
-    resp = do_flash(session, gateway, hexfile, binfile, preverify, verify)
+    resp = do_flash(session, gateway, hexfile, binfile, elffile, preverify, verify, run=False, mcu=mcu)
     stream_output(resp)
 
-    resp = do_reset(ctx.obj.session, gateway, halt=False)
+    resp = do_reset(ctx.obj.session, gateway, halt=False, mcu=mcu)
     stream_output(resp)
 
     job_id = test_run['test_run']['id']
